@@ -1,5 +1,6 @@
 # (C) Copyright 2015-2016 Hewlett Packard Enterprise Development LP
 # Copyright 2016 FUJITSU LIMITED
+# Copyright 2017 SUSE Linux GmbH
 
 """Classes for monitoring the monitoring server stack.
 
@@ -13,10 +14,12 @@ import yaml
 
 from six.moves import configparser
 
+from monasca_agent.common.psutil_wrapper import psutil
 import monasca_setup.agent_config
 import monasca_setup.detection
 from monasca_setup.detection import find_process_cmdline
 from monasca_setup.detection import find_process_name
+from monasca_setup.detection.utils import get_agent_username
 from monasca_setup.detection.utils import watch_process
 from monasca_setup.detection.utils import watch_process_by_username
 
@@ -45,7 +48,7 @@ def _get_impl_lang(process):
     :rtype: str
 
     """
-    p_exe = process.as_dict()['exe']
+    p_exe = process.as_dict(['exe'])['exe']
     for lm in _PYTHON_LANG_MARKERS:
         if lm in p_exe:
             return 'python'
@@ -71,8 +74,8 @@ class MonAgent(monasca_setup.detection.Plugin):
     def build_config(self):
         """Build the config as a Plugins object and return."""
         log.info("\tEnabling the Monasca Agent process check")
-        return watch_process_by_username('mon-agent', 'monasca-agent', 'monitoring',
-                                         'monasca-agent')
+        return watch_process_by_username(get_agent_username(), 'monasca-agent',
+                                         'monitoring', 'monasca-agent')
 
     def dependencies_installed(self):
         return True
@@ -111,10 +114,13 @@ class MonAPI(monasca_setup.detection.Plugin):
 
             """
 
-            p_exe = process.as_dict()['exe']
+            p_exe = process.as_dict(['exe'])['exe']
             for m in _APACHE_MARKERS:
                 if m in p_exe:
-                    return process.parent()
+                    if psutil.version_info < (2, 0):
+                        return process.parent
+                    else:
+                        return process.parent()
             return None
 
         api_process = find_process_cmdline('monasca-api')
@@ -128,7 +134,7 @@ class MonAPI(monasca_setup.detection.Plugin):
                     log.info('\tmonasca-api runs under Apache WSGI')
                     api_process = apache_process
 
-            impl_helper = self._init_impl_helper(api_process.as_dict()['cmdline'],
+            impl_helper = self._init_impl_helper(api_process.as_dict(['cmdline'])['cmdline'],
                                                  impl_lang)
             impl_helper.load_configuration()
 
@@ -193,8 +199,10 @@ class MonNotification(monasca_setup.detection.Plugin):
     def build_config(self):
         """Build the config as a Plugins object and return."""
         log.info("\tEnabling the Monasca Notification healthcheck")
-        return watch_process_by_username('mon-notification', 'monasca-notification', 'monitoring',
-                                         'monasca-notification')
+        notification_process = find_process_cmdline('monasca-notification')
+        notification_user = notification_process.as_dict(['username'])['username']
+        return watch_process_by_username(notification_user, 'monasca-notification',
+                                         'monitoring', 'monasca-notification')
 
     def dependencies_installed(self):
         return True
@@ -218,7 +226,7 @@ class MonPersister(monasca_setup.detection.Plugin):
         if process_found:
             impl_lang = _get_impl_lang(p_process)
             impl_helper = self._init_impl_helper(
-                p_process.as_dict()['cmdline'],
+                p_process.as_dict(['cmdline'])['cmdline'],
                 impl_lang
             )
 
